package com.yiidian.springboot.demo.controller;

import com.yiidian.springboot.demo.pojo.Article;
import com.yiidian.springboot.demo.service.ArticleService;
import com.yiidian.springboot.demo.utils.ResponseResult;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

@Slf4j
@RestController
@RequestMapping("/rest")
public class ArticleController {

  //获取一篇Article，使用GET方法,根据id查询一篇文章
  @GetMapping("/article/{id}")
  public ResponseResult getArticle(@PathVariable("id") Long id){

    Article article = new Article(1L,"Spring Boot入门到精通","Java","Spring Boot入门到精通写得不错哦！",new Date(),null);

    log.info("article:" + article);

    return ResponseResult.success(article);
  }

  //@Autowired
  private ArticleService articleService;

  //增加一篇Article ，使用POST方法(RequestBody方式接收参数)
  @PostMapping("/articles")
  public ResponseResult saveArticle(@RequestBody Article article){

    log.info("saveArticle:" + article);
    return ResponseResult.success(article);
    //return ResponseResult.success(articleService.saveArticle(article));

  }

  //更新一篇Article，使用PUT方法，以id为主键进行更新
  @PutMapping("/articles")
  public ResponseResult updateArticle(@RequestBody Article article){

    log.info("updateArticle:" + article);
    return ResponseResult.success();
  }

  //删除一篇Article，使用DELETE方法，参数是id
  @DeleteMapping("/articles/{id}")
  public ResponseResult deleteArticle(@PathVariable("id") Long id){

    log.info("deleteArticle:" + id);
    return ResponseResult.success();
  }

  @ApiOperation(value = "添加文章", notes = "添加新的文章", tags = "Article",httpMethod = "POST")
  @ApiImplicitParams({
          @ApiImplicitParam(name = "title", value = "文章标题", required = true, dataType = "String"),
          @ApiImplicitParam(name = "content", value = "文章内容", required = true, dataType = "String"),
          @ApiImplicitParam(name = "categoryName", value = "文章类别", required = true, dataType = "String")
  })
  @ApiResponses({
          @ApiResponse(code=200,message="成功",response=ResponseResult.class),
  })
  @PostMapping("/article")
  public @ResponseBody  ResponseResult saveArticle2(
          @RequestParam(value="title") String title,  //参数1
          @RequestParam(value="content") String content,//参数2
          @RequestParam(value="categoryName") String categoryName//参数3
  ) {
    log.info("添加文章");
    return ResponseResult.success();
  }
}
